<!--- docs/index.md -->
# zbinfigs

```{toctree}
:maxdepth: 2
:hidden:

```

```{include} ../README.md
:start-after: <!-- SPHINX-START -->
```

`zbinfigs` is a simple python package to support classification of figures from a zotero collection of scholarly articles.  

## Installation  

You can install the package by calling:

```bash
pip install git+https://github.com/spackman/zbinfigs
```
## Usage
<!-- SPHINX-START -->

## Indices and tables

- {ref}`genindex`
- {ref}`modindex`
- {ref}`search`
